<?php
/**
 * @file
 * Contains \Drupal\spectra_connect\Form\SpectraConnectEntityForm.
 */

namespace Drupal\spectra_connect\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\spectra_connect\Entity\SpectraConnect;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the spectra_connect entity edit forms.
 *
 * @ingroup spectra_connect
 */
class SpectraConnectForm extends EntityForm {

  /**
   * Constructs an SpectraConnectForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entityTypeManager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * Build Bundle Type List
   */
  public function createEntityList() {
    $ret = array();
    foreach(\Drupal::entityTypeManager()->getDefinitions() as $type => $info) {
      // is this a content/front-facing entity?
      if ($info instanceof \Drupal\Core\Entity\ContentEntityType) {
        $label = $info->getLabel();
        if ($label instanceof \Drupal\Core\StringTranslation\TranslatableMarkup) {
          $label = $label->render();
        }
        $ret[$type] = $label;
      }
    }
    return $ret;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    /* @var $entity \Drupal\spectra_connect\Entity\SpectraConnectEntity */
    $form = parent::form($form, $form_state);
    $ent = $this->entity;

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $ent->label(),
      '#description' => $this->t("Label for the Spectra Connect Entity."),
      '#required' => TRUE,
    ];

    $form['id'] = array(
      '#type' => 'machine_name',
      '#default_value' => $ent->id(),
      '#machine_name' => [
        'exists' => [$this, 'exist'],
      ],
      '#disabled' => !$ent->isNew(),
    );

    $form['plugin'] = array(
      '#title' => t('Plugin'),
      '#description' => t('The Spectra plugin to use. Leave blank for the default.'),
      '#type' => 'textfield',
      '#required' => FALSE,
      '#default_value' => isset($ent->plugin) ? $ent->plugin : '',
    );

    $form['delete_endpoint'] = array(
      '#title' => t('Spectra DELETE Endpoint'),
      '#description' => t('The endpoint for sending DELETE requests.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($ent->delete_endpoint) ? $ent->delete_endpoint : '',
    );

    $form['get_endpoint'] = array(
      '#title' => t('Spectra GET Endpoint'),
      '#description' => t('The endpoint for sending GET requests.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($ent->get_endpoint) ? $ent->get_endpoint : '',
    );

    $form['post_endpoint'] = array(
      '#title' => t('Spectra POST Endpoint'),
      '#description' => t('The endpoint for sending POST requests.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($ent->post_endpoint) ? $ent->post_endpoint : '',
    );

    $form['api_key'] = array(
      '#title' => t('API Key'),
      '#description' => t('The API key for accessing the Spectra server. You will need to get a key from the server.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($ent->api_key) ? $ent->api_key : '',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    // Redirect to term list after save.
    $form_state->setRedirect('entity.spectra_connect.collection');
    $entity = $this->entity;
    $entity->save();
  }

  /**
   * Helper function to check whether an Spectra ConnectEntity configuration entity exists.
   */
  public function exist($id) {
    $entity = $this->entityTypeManager->getStorage('spectra_connect')->getQuery()
      ->condition('id', $id)
      ->execute();
    return (bool) $entity;
  }
}
