<?php

/**
 * @file
 *
 * Utility file for Spectra Connect API operations
 */

namespace Drupal\spectra_connect;

use Drupal\spectra_connect\Entity\SpectraConnect;
use GuzzleHttp\Exception\ClientException;

/**
 * Class SpectraConnectUtilities
 * @package Drupal\spectra_connect
 *
 * Utility class
 */
class SpectraConnectUtilities {

  public function __construct() {

  }

  /**
   * @param $connector
   * @param $data
   */
  public static function spectra_queue_delete($connector, $data) {
    $queue_factory = \Drupal::service('queue');
    $queue = $queue_factory->get('spectra_connect_queue_delete');
    $item = new \stdClass();
    $item->connector = $connector;
    $item->data = $data;
    $queue->createItem($item);
  }

  public static function spectra_delete($connector, $data) {
    $conn = SpectraConnect::load($connector);
    if ($conn) {
      $plugin = $conn->plugin;
      if ($plugin) {
        $data['plugin'] = $plugin;
      }
      $endpoint = $conn->delete_endpoint;
      $api_key = $conn->api_key;
      $headers = [];
      $headers['api-key'] = $api_key;
      $headers['Accept'] = 'application/json';
      $headers['Content-type'] = 'application/json';
      $options = ['headers' => $headers, 'body' => json_encode($data)];
      try {
        $response = \Drupal::httpClient()->delete($endpoint, $options);
        return $response;
      }
      catch (ClientException $e) {
        watchdog_exception('spectra_connect', $e);
        return FALSE;
      }
    }
    else {
      return FALSE;
    }
  }

  public static function spectra_get($connector, $data) {
    $conn = SpectraConnect::load($connector);
    if ($conn) {
      $plugin = $conn->plugin;
      if ($plugin) {
        $data['plugin'] = $plugin;
      }
      $endpoint = $conn->get_endpoint;
      $api_key = $conn->api_key;
      $headers = [];
      $headers['api-key'] = $api_key;
      $headers['Accept'] = 'application/json';
      $headers['Content-type'] = 'application/json';

      // Build query string
      // TODO add the Url class, and build the URL the right way
      $query_string = http_build_query($data);
      $query_append = strpos($endpoint, '?') !== FALSE ? '&' : '?';
      $url = $endpoint . $query_append . $query_string;
      $options = ['headers' => $headers];
      try {
        $response = \Drupal::httpClient()->get($url, $options);
        return $response;
      }
      catch (ClientException $e) {
        watchdog_exception('spectra_connect', $e);
        return FALSE;
      }
    }
    else {
      return FALSE;
    }
  }

  /**
   * @param $connector
   * @param $data
   */
  public static function spectra_queue_post($connector, $data) {
    $queue_factory = \Drupal::service('queue');
    $queue = $queue_factory->get('spectra_connect_queue_post');
    $item = new \stdClass();
    $item->connector = $connector;
    $item->data = $data;
    $queue->createItem($item);
  }

  public static function spectra_post($connector, $data) {
    $conn = SpectraConnect::load($connector);
    if ($conn) {
      $plugin = $conn->plugin;
      if ($plugin) {
        $data['plugin'] = $plugin;
      }
      $endpoint = $conn->post_endpoint;
      $api_key = $conn->api_key;
      $headers = [];
      $headers['api-key'] = $api_key;
      $headers['Accept'] = 'application/json';
      $headers['Content-type'] = 'application/json';
      $options = ['headers' => $headers, 'body' => json_encode($data)];
      try {
        $response = \Drupal::httpClient()->post($endpoint, $options);
        return $response;
      }
      catch (ClientException $e) {
        watchdog_exception('spectra_connect', $e);
        return FALSE;
      }
    }
    else {
      return FALSE;
    }
  }

}